aboutsummaryrefslogtreecommitdiff
path: root/hardinfo/hardinfo.c
diff options
context:
space:
mode:
Diffstat (limited to 'hardinfo/hardinfo.c')
-rw-r--r--hardinfo/hardinfo.c18
1 files changed, 11 insertions, 7 deletions
diff --git a/hardinfo/hardinfo.c b/hardinfo/hardinfo.c
index e1783315..d1d228b3 100644
--- a/hardinfo/hardinfo.c
+++ b/hardinfo/hardinfo.c
@@ -92,13 +92,17 @@ int main(int argc, char **argv)
}
if (!params.create_report && !params.run_benchmark) {
- /* we only try to open the UI if the user didn't ask for a report. */
- params.gui_running = ui_init(&argc, &argv);
-
- /* as a fallback, if GTK+ initialization failed, run in report
- generation mode. */
- if (!params.gui_running)
- params.create_report = TRUE;
+ /* we only try to open the UI if the user didn't ask for a report. */
+ params.gui_running = ui_init(&argc, &argv);
+
+ /* as a fallback, if GTK+ initialization failed, run in report
+ generation mode. */
+ if (!params.gui_running) {
+ params.create_report = TRUE;
+ /* ... it is possible to -f html without -r */
+ if (params.report_format != REPORT_FORMAT_HTML)
+ params.markup_ok = FALSE;
+ }
}
if (params.use_modules) {